@@ -12,7 +12,8 @@ from gevent import monkey
 from gevent.pywsgi import WSGIServer
 from geventwebsocket.handler import WebSocketHandler
 from Utils import ReidsClient
-from .settings import *
+from proxy.scheduler import Scheduler
+
 
 monkey.patch_all()
 app = Flask(__name__)
@@ -23,21 +24,27 @@ app.config.update(
 CORS(app, supports_credentials=True)
 
 
-def get_conn():
+def get_conn(config):
     if not hasattr(g, 'redis_client'):
         g.redis_client = ReidsClient(
-            name=PROXY_NAME,
-            config={"HOST": HOST, "PORT": PORT, "DB": DB}
+            name=config.get("PROXY_NAME"),
+            config={"HOST": config.get("HOST"), "PORT": config.get("PORT"), "DB": config.get("DB"),
+                    "PAW": config.get("PASSWORD")}
         )
     return g.redis_client
 
 
 @app.route('/get', methods=["post", "get"])
 def detail():
-    res = get_conn().redis_conn
-    ip = request.remote_addr
     key = request.args.to_dict().get("key")
+    host = request.args.to_dict().get("HOST")
+    port = request.args.to_dict().get("PORT")
     count = request.args.to_dict().get("count")
+    ip = request.remote_addr
+
+    s = Scheduler(host, int(port))
+    config = s.config
+    res = get_conn(config).redis_conn
     logging.info(key)
     if key == "228923910":
         if res.exists(ip):
@@ -48,7 +55,7 @@ def detail():
             # get_conn().put("ssssssss")
             return {
                 "code": 200,
-                "data": res.srandmember(PROXY_NAME, number=count),
+                "data": res.srandmember(config.get("PROXY_NAME"), number=count),
                 "msg": ""
             }
         else:
@@ -65,7 +72,7 @@ def detail():
         }
 
 
-if __name__ == '__main__':
-    app.run(host='0.0.0.0', port=8282)
-    http_server = WSGIServer(('0.0.0.0', 8282), app, handler_class=WebSocketHandler)
+def main(host, port):
+    app.run(host=host, port=port)
+    http_server = WSGIServer((host, port), app, handler_class=WebSocketHandler)
     http_server.serve_forever()
